@@ -1,65 +1,51 @@
 package CPANPLUS::Internals::Constants;
 
 use strict;
-
+use CPANPLUS::inc;
 use CPANPLUS::Error;
 
-use Config;
 use File::Spec;
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 
-require Exporter;
-use vars    qw[$VERSION @ISA @EXPORT];
-
-use Package::Constants;
-
-@ISA        = qw[Exporter];
-@EXPORT     = Package::Constants->list( __PACKAGE__ );
+### for the version number ###
+require CPANPLUS::Internals;
 
 
-sub constants { @EXPORT };
+BEGIN {
+
+    require Exporter;
+    use vars    qw[$VERSION @ISA @EXPORT];
+  
+    $VERSION    = 0.01;
+    @ISA        = qw[Exporter];
+    @EXPORT     = qw[   
+                    FILE_EXISTS FILE_READABLE DIR_EXISTS IS_MODOBJ IS_AUTHOBJ 
+                    MAKEFILE MAKEFILE_PL BUILD_PL BUILD BUILD_DIR PREREQ_BUILD    
+                    IS_FAKE_MODOBJ IS_FAKE_AUTHOBJ README CHECKSUMS OPEN_FILE
+                    PGP_HEADER ENV_CPANPLUS_CONFIG DEFAULT_EMAIL DOT_CPANPLUS
+                    CPANPLUS_UA TESTERS_URL TESTERS_DETAILS_URL BLIB ARCH LIB
+                    DOT_SHELL_DEFAULT_RC PREREQ_INSTALL PREREQ_ASK IS_CONFOBJ 
+                    PREREQ_IGNORE BOOLEANS CALLING_FUNCTION IS_RVOBJ LIB_DIR
+                    ARCH_DIR DOT_EXISTS AUTO LIB_AUTO_DIR ARCH_AUTO_DIR    
+                    PERL_CORE IS_INTERNALS_OBJ IS_CODEREF CREATE_FILE_URI   
+                    STRIP_GZ_SUFFIX BLIB_LIBDIR GET_XS_FILES INSTALLER_BUILD
+                    INSTALLER_MM ON_OLD_CYGWIN IS_FILE IS_DIR INSTALLER_SAMPLE
+                    INSTALL_VIA_PACKAGE_MANAGER TARGET_CREATE TARGET_PREPARE
+                    TARGET_INSTALL TARGET_IGNORE
+                ];
+}
 
 use constant INSTALLER_BUILD
                             => 'CPANPLUS::Dist::Build';
 use constant INSTALLER_MM   => 'CPANPLUS::Dist::MM';    
 use constant INSTALLER_SAMPLE   
                             => 'CPANPLUS::Dist::Sample';
-use constant INSTALLER_BASE => 'CPANPLUS::Dist::Base';  
-use constant INSTALLER_AUTOBUNDLE
-                            => 'CPANPLUS::Dist::Autobundle';
-
-use constant SHELL_DEFAULT  => 'CPANPLUS::Shell::Default';
-use constant SHELL_CLASSIC  => 'CPANPLUS::Shell::Classic';
-
-use constant CONFIG         => 'CPANPLUS::Config';
-use constant CONFIG_USER    => 'CPANPLUS::Config::User';
-use constant CONFIG_SYSTEM  => 'CPANPLUS::Config::System';
-use constant CONFIG_BOXED   => 'CPANPLUS::Config::Boxed';
-
-use constant DEFAULT_SOURCE_ENGINE
-                            => 'CPANPLUS::Internals::Source::Memory';
 
 use constant TARGET_CREATE  => 'create';
 use constant TARGET_PREPARE => 'prepare';
 use constant TARGET_INSTALL => 'install';
 use constant TARGET_IGNORE  => 'ignore';
 
-use constant ON_WIN32       => $^O eq 'MSWin32';
-use constant ON_NETWARE     => $^O eq 'NetWare';
-use constant ON_CYGWIN      => $^O eq 'cygwin';
-use constant ON_VMS         => $^O eq 'VMS';
-
-use constant DOT_CPANPLUS   => ON_VMS ? '_cpanplus' : '.cpanplus'; 
-
-use constant OPT_AUTOFLUSH  => '-MCPANPLUS::Internals::Utils::Autoflush';
-
-use constant UNKNOWN_DL_LOCATION
-                            => 'UNKNOWN-ORIGIN';   
-
-use constant NMAKE          => 'nmake.exe';
-use constant NMAKE_URL      => 
-                        'ftp://ftp.microsoft.com/Softlib/MSLFILES/nmake15.exe';
-
 use constant INSTALL_VIA_PACKAGE_MANAGER 
                             => sub { my $fmt = $_[0] or return;
                                      return 1 if $fmt ne INSTALLER_BUILD and
@@ -119,107 +105,66 @@ use constant DIR_EXISTS     => sub {
                                             $dir));
                                     return;
                             };   
-                    
-                            ### On VMS, if the $Config{make} is either MMK 
-                            ### or MMS, then the makefile is 'DESCRIP.MMS'.
-use constant MAKEFILE       => sub { my $file =
-                                        (ON_VMS and 
-                                         $Config::Config{make} =~ /MM[S|K]/i)
-                                            ? 'DESCRIP.MMS'
-                                            : 'Makefile';
 
-                                    return @_
-                                        ? File::Spec->catfile( @_, $file )
-                                        : $file;
-                            };                   
 use constant MAKEFILE_PL    => sub { return @_
-                                        ? File::Spec->catfile( @_,
+                                        ? File::Spec->catfile( $_[0],
                                                             'Makefile.PL' )
                                         : 'Makefile.PL';
+                            };                   
+use constant MAKEFILE       => sub { return @_
+                                        ? File::Spec->catfile( $_[0],
+                                                            'Makefile' )
+                                        : 'Makefile';
                             }; 
 use constant BUILD_PL       => sub { return @_
-                                        ? File::Spec->catfile( @_,
+                                        ? File::Spec->catfile( $_[0],
                                                             'Build.PL' )
                                         : 'Build.PL';
                             };
-                      
-use constant META_YML       => sub { return @_
-                                        ? File::Spec->catfile( @_, 'META.yml' )
-                                        : 'META.yml';
+use constant BUILD_DIR      => sub { return @_
+                                        ? File::Spec->catdir($_[0], '_build')
+                                        : '_build';
                             }; 
-
+use constant BUILD          => sub { return @_
+                                        ? File::Spec->catfile($_[0], 'Build')
+                                        : 'Build';
+                            };
 use constant BLIB           => sub { return @_
-                                        ? File::Spec->catfile(@_, 'blib')
+                                        ? File::Spec->catfile($_[0], 'blib')
                                         : 'blib';
                             };                  
 
 use constant LIB            => 'lib';
 use constant LIB_DIR        => sub { return @_
-                                        ? File::Spec->catdir(@_, LIB)
+                                        ? File::Spec->catdir($_[0], LIB)
                                         : LIB;
                             }; 
 use constant AUTO           => 'auto';                            
 use constant LIB_AUTO_DIR   => sub { return @_
-                                        ? File::Spec->catdir(@_, LIB, AUTO)
+                                        ? File::Spec->catdir($_[0], LIB, AUTO)
                                         : File::Spec->catdir(LIB, AUTO)
                             }; 
 use constant ARCH           => 'arch';
 use constant ARCH_DIR       => sub { return @_
-                                        ? File::Spec->catdir(@_, ARCH)
+                                        ? File::Spec->catdir($_[0], ARCH)
                                         : ARCH;
                             }; 
 use constant ARCH_AUTO_DIR  => sub { return @_
-                                        ? File::Spec->catdir(@_,ARCH,AUTO)
+                                        ? File::Spec->catdir($_[0],ARCH,AUTO)
                                         : File::Spec->catdir(ARCH,AUTO)
                             };                            
 
 use constant BLIB_LIBDIR    => sub { return @_
                                         ? File::Spec->catdir(
-                                                @_, BLIB->(), LIB )
+                                                $_[0], BLIB->(), LIB )
                                         : File::Spec->catdir( BLIB->(), LIB );
                             };  
-
-use constant CONFIG_USER_LIB_DIR => sub { 
-                                    require CPANPLUS::Internals::Utils;
-                                    LIB_DIR->(
-                                        CPANPLUS::Internals::Utils->_home_dir,
-                                        DOT_CPANPLUS
-                                    );
-                                };        
-use constant CONFIG_USER_FILE    => sub {
-                                    File::Spec->catfile(
-                                        CONFIG_USER_LIB_DIR->(),
-                                        split('::', CONFIG_USER),
-                                    ) . '.pm';
-                                };
-use constant CONFIG_SYSTEM_FILE  => sub {
-                                    require CPANPLUS::Internals;
-                                    require File::Basename;
-                                    my $dir = File::Basename::dirname(
-                                        $INC{'CPANPLUS/Internals.pm'}
-                                    );
-                                
-                                    ### XXX use constants
-                                    File::Spec->catfile( 
-                                        $dir, qw[Config System.pm]
-                                    );
-                                };        
-      
 use constant README         => sub { my $obj = $_[0];
                                      my $pkg = $obj->package_name;
                                      $pkg .= '-' . $obj->package_version .
                                              '.readme';
                                      return $pkg;
                             };
-use constant META_EXT       => 'meta';
-
-use constant META           => sub { my $obj = $_[0];
-                                     my $pkg = $obj->package_name;
-                                     $pkg .= '-' . $obj->package_version .
-                                             '.' . META_EXT;
-                                     return $pkg;
-                            };                          
-                            
 use constant OPEN_FILE      => sub {
                                     my($file, $mode) = (@_, '');
                                     my $fh;
@@ -230,35 +175,7 @@ use constant OPEN_FILE      => sub {
                                     return $fh if $fh;
                                     return;
                             };      
-         
-use constant OPEN_DIR       => sub { 
-                                    my $dir = shift;
-                                    my $dh;
-                                    opendir $dh, $dir or error(loc(
-                                        "Could not open dir '%1': %2", $dir, $!
-                                    ));
-                                    
-                                    return $dh if $dh;
-                                    return;
-                            };
-
-use constant READ_DIR       => sub { 
-                                    my $dir = shift;
-                                    my $dh  = OPEN_DIR->( $dir ) or return;
-                                    
-                                    ### exclude . and ..
-                                    my @files =  grep { $_ !~ /^\.{1,2}/ }
-                                                    readdir($dh);
-
-                                    ### Remove trailing dot on VMS when
-                                    ### using VMS syntax.
-                                    if( ON_VMS ) {
-                                        s/(?<!\^)\.$// for @files;
-                                    }
-                                    
-                                    return @files;
-                            };  
-
+                            
 use constant STRIP_GZ_SUFFIX 
                             => sub {
                                     my $file = $_[0] or return;
@@ -270,41 +187,29 @@ use constant CHECKSUMS      => 'CHECKSUMS';
 use constant PGP_HEADER     => '-----BEGIN PGP SIGNED MESSAGE-----';
 use constant ENV_CPANPLUS_CONFIG
                             => 'PERL5_CPANPLUS_CONFIG';
-use constant ENV_CPANPLUS_IS_EXECUTING
-                            => 'PERL5_CPANPLUS_IS_EXECUTING';
 use constant DEFAULT_EMAIL  => 'cpanplus@example.com';   
-use constant CPANPLUS_UA    => sub { ### for the version number ###
-                                     require CPANPLUS::Internals;
-                                     "CPANPLUS/$CPANPLUS::Internals::VERSION" 
-                                };
+use constant DOT_CPANPLUS   => '.cpanplus';         
+use constant CPANPLUS_UA    => sub { "CPANPLUS/$CPANPLUS::Internals::VERSION" };
 use constant TESTERS_URL    => sub {
-                                    'http://cpantesters.org/distro/'.
-                                    uc(substr($_[0],0,1)) .'/'. $_[0] . '.yaml';
+                                    "http://testers.cpan.org/show/" .
+                                    $_[0] .".yaml" 
                                 };
 use constant TESTERS_DETAILS_URL
                             => sub {
-                                    'http://cpantesters.org/distro/'.
-                                    uc(substr($_[0],0,1)) .'/'. $_[0];
+                                    'http://testers.cpan.org/show/' .
+                                    $_[0] . '.html';
                                 };         
 
 use constant CREATE_FILE_URI    
                             => sub { 
                                     my $dir = $_[0] or return;
                                     return $dir =~ m|^/| 
-                                        ? 'file://'  . $dir
-                                        : 'file:///' . $dir;   
+                                        ? 'file:/'  . $dir
+                                        : 'file://' . $dir;   
                             };        
 
-use constant EMPTY_DSLIP    => '     ';
-
-use constant CUSTOM_AUTHOR_ID
-                            => 'LOCAL';
-
 use constant DOT_SHELL_DEFAULT_RC
                             => '.shell-default.rc';
-                            
-use constant SOURCE_SQLITE_DB
-                            => 'db.sql';
 
 use constant PREREQ_IGNORE  => 0;                
 use constant PREREQ_INSTALL => 1;
@@ -315,8 +220,8 @@ use constant CALLING_FUNCTION
                             => sub { my $lvl = $_[0] || 0;
                                      return join '::', (caller(2+$lvl))[3] 
                                 };
+use constant DOT_EXISTS     => '.exists';     
 use constant PERL_CORE      => 'perl';
-use constant STORABLE_EXT   => '.stored';
 
 use constant GET_XS_FILES   => sub { my $dir = $_[0] or return;
                                      require File::Find;
@@ -329,36 +234,12 @@ use constant GET_XS_FILES   => sub { my $dir = $_[0] or return;
                                      return @files;
                                 };  
 
-use constant INSTALL_LOG_FILE 
-                            => sub { my $obj  = shift or return;
-                                     my $name = $obj->name; $name =~ s/::/-/g;
-                                     $name .= '-'. $obj->version;
-                                     $name .= '-'. scalar(time) . '.log';
-                                     return $name;
-                                };                                        
-
-use constant ON_OLD_CYGWIN  => do { ON_CYGWIN and $] < 5.008 
-                                    ? loc(
-                                       "Your perl version for %1 is too low; ".
-                                       "Require %2 or higher for this function",
-                                       $^O, '5.8.0' )
+use constant ON_OLD_CYGWIN  => do { $^O eq 'cygwin' and $] < 5.008 
+                                    ? loc("Your perl version for %1 is too low; ".
+                                            "Require %2 or higher for this function",
+                                            $^O, '5.8.0' )
                                     : '';                                                                           
                                 };
-
-### XXX these 2 are probably obsolete -- check & remove;
-use constant DOT_EXISTS     => '.exists'; 
-
-use constant QUOTE_PERL_ONE_LINER 
-                            => sub { my $line = shift or return;
-
-                                     ### use double quotes on these systems
-                                     return qq["$line"] 
-                                        if ON_WIN32 || ON_NETWARE || ON_VMS;
-
-                                     ### single quotes on the rest
-                                     return qq['$line'];
-                            };   
-
 1;              
 
 # Local variables:
