@@ -1,9 +1,8 @@
 package CPANPLUS::Module::Author;
 
 use strict;
-
+use CPANPLUS::inc;
 use CPANPLUS::Error;
-use CPANPLUS::Internals::Constants;
 use Params::Check               qw[check];
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 
@@ -17,7 +16,7 @@ CPANPLUS::Module::Author
 
 =head1 SYNOPSIS
 
-    my $author = CPANPLUS::Module::Author->new(
+    my $author = CPANPLUS::Author->new(
                     author  => 'Jack Ashton',
                     cpanid  => 'JACKASH',
                     _id     => INTERNALS_OBJECT_ID,
@@ -30,11 +29,11 @@ CPANPLUS::Module::Author
     @dists  = $author->distributions;
     @mods   = $author->modules;
 
-    @accessors = CPANPLUS::Module::Author->accessors;
+    @accessors = CPANPLUS::Author->accessors;
 
 =head1 DESCRIPTION
 
-C<CPANPLUS::Module::Author> creates objects from the information in the
+C<CPANPLUS::Author> creates objects from the information in the
 source files. These can then be used to query on.
 
 These objects should only be created internally. For C<fake> objects,
@@ -46,7 +45,7 @@ An objects of this class has the following accessors:
 
 =over 4
 
-=item author
+=item name
 
 Name of the author.
 
@@ -94,9 +93,9 @@ sub parent {
 
 =head1 METHODS
 
-=head2 $auth = CPANPLUS::Module::Author->new( author => AUTHOR_NAME, cpanid => CPAN_ID, _id => INTERNALS_ID [, email => AUTHOR_EMAIL] )
+=head2 $auth = CPANPLUS::Author->new( author => AUTHOR_NAME, cpanid => CPAN_ID, _id => INTERNALS_ID [, email => AUTHOR_EMAIL] )
 
-This method returns a C<CPANPLUS::Module::Author> object, based on the given
+This method returns a C<CPANPLUS::Author> object, based on the given
 parameters.
 
 Returns false on failure.
@@ -174,33 +173,13 @@ sub distributions {
     my $href = $mod->_parse_checksums_file( file => $file ) or return;
 
     my @rv;
-    for my $name ( keys %$href ) {
+    for my $dist ( keys %$href ) {
+        my $clone = $mod->clone;
 
-        ### shortcut asap, so we avoid extra ops. On big checksums files
-        ### the call to clone() takes up a lot of time.
-        ### .meta files are now also in the checksums file,
-        ### which means we have to filter out things that dont
-        ### match our regex
-        next if $mod->package_extension( $name ) eq META_EXT;
-
-        ### used to do this wiht ->clone. However, that calls ->dslip,
-        ### (which is wrong anyway, as we're doing a different module),
-        ### which in turn calls ->contains, which scans the entire
-        ### module tree using _search_module_tree, which uses P::C
-        ### and is therefor VERY VERY slow.
-        ### so let's do this the direct way for speed ups.
-        my $dist = CPANPLUS::Module::Fake->new(
-                        module  =>  do { my $m = $mod->package_name( $name );
-                                         $m =~ s/-/::/g; $m;
-                                    },      
-                        version =>  $mod->package_version(  $name ),
-                        package =>  $name,
-                        path    =>  $mod->path,     # same author after all
-                        author  =>  $mod->author,   # same author after all
-                        mtime   =>  $href->{$name}->{'mtime'},  # release date
-                    );
-
-        push @rv, $dist;
+        $clone->package( $dist );
+        $clone->module( $clone->package_name );
+        $clone->version( $clone->package_version );
+        push @rv, $clone;
     }
 
     return @rv;
