@@ -3,7 +3,7 @@ package CPANPLUS::Module::Checksums;
 use strict;
 use vars qw[@ISA];
 
-
+use CPANPLUS::inc;
 use CPANPLUS::Error;
 use CPANPLUS::Internals::Constants;
 
@@ -61,7 +61,7 @@ sub checksums {
 ### checks if the package checksum matches the one
 ### from the checksums file
 sub _validate_checksum {
-    my $self = shift; #must be isa CPANPLUS::Module
+    my $self = shift;
     my $conf = $self->parent->configure_object;
     my %hash = @_;
 
@@ -76,33 +76,16 @@ sub _validate_checksum {
     ### if we can't check it, we must assume it's ok ###
     return $self->status->checksum_ok(1)
             unless can_load( modules => { 'Digest::MD5' => '0.0' } );
-    #class CPANPLUS::Module::Status is runtime-generated
 
     my $file = $self->_get_checksums_file( verbose => $verbose ) or (
         error(loc(q[Could not fetch '%1' file], CHECKSUMS)), return );
 
     $self->_check_signature_for_checksum_file( file => $file ) or (
         error(loc(q[Could not verify '%1' file], CHECKSUMS)), return );
-    #for whole CHECKSUMS file
 
     my $href = $self->_parse_checksums_file( file => $file ) or (
         error(loc(q[Could not parse '%1' file], CHECKSUMS)), return );
 
-    my $size = $href->{ $self->package }->{'size'};
-
-    ### the checksums file tells us the size of the archive
-    ### but the downloaded file is of different size
-    if( defined $size ) {
-        if( not (-s $self->status->fetch == $size) ) {
-            error(loc(  "Archive size does not match for '%1': " .
-                        "size is '%2' but should be '%3'",
-                        $self->package, -s $self->status->fetch, $size));
-            return $self->status->checksum_ok(0);
-        }
-    } else {
-        msg(loc("Archive size is not known for '%1'",$self->package),$verbose);
-    }
-    
     my $md5 = $href->{ $self->package }->{'md5'};
 
     unless( defined $md5 ) {
@@ -141,7 +124,7 @@ sub _get_checksums_file {
     my $clone = $self->clone;
     $clone->package( CHECKSUMS );
 
-    my $file = $clone->fetch( ttl => 3600, %hash ) or return;
+    my $file = $clone->fetch( %hash, force => 1 ) or return;
 
     return $file;
 }
@@ -160,7 +143,7 @@ sub _parse_checksums_file {
 
     ### loop over the header, there might be a pgp signature ###
     my $signed;
-    while (local $_ = <$fh>) {
+    while (<$fh>) {
         last if /^\$cksum = \{\s*$/;    # skip till this line
         my $header = PGP_HEADER;        # but be tolerant of whitespace
         $signed = 1 if /^${header}\s*$/;# due to crossplatform linebreaks
@@ -170,7 +153,7 @@ sub _parse_checksums_file {
     ### *should* be valid perl code
     my $dist;
     my $cksum = {};
-    while (local $_ = <$fh>) {
+    while (<$fh>) {
 
         if (/^\s*'([^']+)' => \{\s*$/) {
             $dist = $1;
@@ -214,7 +197,7 @@ sub _check_signature_for_checksum_file {
     my $fh = OPEN_FILE->($file) or return;
 
     my $signed;
-    while (local $_ = <$fh>) {
+    while (<$fh>) {
         my $header = PGP_HEADER;
         $signed = 1 if /^$header$/;
     }
