@@ -1,32 +1,13 @@
 package CPANPLUS::inc;
 
-=head1 NAME
-
-CPANPLUS::inc
-
-=head1 DESCRIPTION
-
-OBSOLETE
-
-=cut
-
-sub original_perl5opt   { $ENV{PERL5OPT}    };
-sub original_perl5lib   { $ENV{PERL5LIB}    };
-sub original_inc        { @INC              };
-
-1;
-
-__END__
-
 use strict;
-use vars        qw[$DEBUG $VERSION $ENABLE_INC_HOOK %LIMIT $QUIET];
+use vars        qw[$DEBUG $VERSION $ENABLE_INC_HOOK %LIMIT];
 use File::Spec  ();
 use Config      ();
 
 ### 5.6.1. nags about require + bareword otherwise ###
 use lib ();
 
-$QUIET              = 0;
 $DEBUG              = 0;
 %LIMIT              = ();
 
@@ -38,7 +19,7 @@ CPANPLUS::inc - runtime inclusion of privately bundled modules
 
 =head1 SYNOPSIS
 
-    ### set up CPANPLUS::inc to do its thing ###
+    ### set up CPANPLUS::inc to do it's thing ###
     BEGIN { use CPANPLUS::inc };
 
     ### enable debugging ###
@@ -136,7 +117,7 @@ include facility from C<CPANPLUS::inc>. It will roughly look like:
 
     sub original_perl5opt   { $org_opt || ''};
     sub original_perl5lib   { $org_lib || ''};
-    sub original_inc        { @org_inc, __PACKAGE__->my_path };
+    sub original_inc        { @org_inc };
 
     sub limited_perl5opt    {
         my $pkg = shift;
@@ -170,17 +151,15 @@ It would looks something like this:
 
 {
     my $map = {
-        ### used to have 0.80, but not it was never released by coral
-        ### 0.79 *should* be good enough for now... asked coral to 
-        ### release 0.80 on 10/3/2006
-        'IPC::Run'                  => '0.79', 
         'File::Fetch'               => '0.07',
         #'File::Spec'                => '0.82', # can't, need it ourselves...
+        'IPC::Run'                  => '0.77',
         'IPC::Cmd'                  => '0.24',
         'Locale::Maketext::Simple'  => 0,
         'Log::Message'              => 0,
         'Module::Load'              => '0.10',
         'Module::Load::Conditional' => '0.07',
+        'Module::Build'             => '0.2607',
         'Params::Check'             => '0.22',
         'Term::UI'                  => '0.05',
         'Archive::Extract'          => '0.07',
@@ -189,7 +168,6 @@ It would looks something like this:
         'Object::Accessor'          => '0.03',
         'Module::CoreList'          => '1.97',
         'Module::Pluggable'         => '2.4',
-        'Module::Loaded'            => 0,
         #'Config::Auto'             => 0,   # not yet, not using it yet
     };
 
@@ -271,12 +249,8 @@ find out exactly what C<CPANPLUS::inc> is doing.
         my $pkg = shift;
 
         ### filter DEBUG, and toggle the global
-        map { $LIMIT{$_} = 1 }  
-            grep {  /DEBUG/ ? ++$DEBUG && 0 : 
-                    /QUIET/ ? ++$QUIET && 0 :
-                    1 
-            } @_;
-        
+        map { $LIMIT{$_} = 1 }  grep { /DEBUG/ ? ++$DEBUG && 0 : 1 } @_;
+
         ### only load once ###
         return 1 if $Loaded++;
 
@@ -305,16 +279,15 @@ find out exactly what C<CPANPLUS::inc> is doing.
         ### we care about. very basic check, but will
         ### have to do for now.
         lib->import( sub {
-            my $path    = pop();                    # path to the pm
-            my $module  = $path or return;          # copy of the path, to munge
-            my @parts   = split qr!\\|/!, $path;    # dirs + file name; could be
-                                                    # win32 paths =/
-            my $file    = pop @parts;               # just the file name
+            my $path    = pop();                # path to the pm
+            my $module  = $path or return;      # copy of the path, to munge
+            my @parts   = split '/', $path;     # dirs + file name
+            my $file    = pop @parts;           # just the file name
             my $map     = __PACKAGE__->interesting_modules;
 
-            ### translate file name to module name 
-            ### could contain win32 paths delimiters
-            $module =~ s!/|\\!::!g; $module =~ s/\.pm//i;
+
+            ### translate file name to module name ###
+            $module =~ s|/|::|g; $module =~ s/\.pm//i;
 
             my $check_version; my $try;
             ### does it look like a module we care about?
@@ -407,7 +380,7 @@ find out exactly what C<CPANPLUS::inc> is doing.
             ### or otherwise, the one not bundled
             ### or otherwise the newest
             my @sorted = sort {
-                            _vcmp($b->[0], $a->[0])                  ||
+                            ($b->[0] <=> $a->[0])                   ||
                             ($Cache{$interesting}
                                 ?($b->[2] eq $Cache{$interesting}->[0][2]) <=>
                                  ($a->[2] eq $Cache{$interesting}->[0][2])
@@ -421,14 +394,12 @@ find out exactly what C<CPANPLUS::inc> is doing.
                              ."'$sorted[0][2]' with version '$sorted[0][0]'\n"
                     if $DEBUG;
 
-            if( $check_version and 
-                not (_vcmp($sorted[0][0], $map->{$module}) >= 0) 
-            ) {
+            if( $check_version and not ($sorted[0][0] >= $map->{$module}) ) {
                 warn __PACKAGE__ .": Cannot find high enough version for "
                                  ."'$module' -- need '$map->{$module}' but "
                                  ."only found '$sorted[0][0]'. Returning "
                                  ."highest found version but this may cause "
-                                 ."problems\n" unless $QUIET;
+                                 ."problems\n";
             };
 
             ### right, so that damn )#$(*@#)(*@#@ Module::Build makes
@@ -458,13 +429,6 @@ find out exactly what C<CPANPLUS::inc> is doing.
     }
 }
 
-### XXX copied from C::I::Utils, so there's no circular require here!
-sub _vcmp {
-    my ($x, $y) = @_;
-    s/_//g foreach $x, $y;
-    return $x <=> $y;
-}
-
 =pod
 
 =head1 DEBUG
