@@ -54,19 +54,13 @@ sub resume {
   return $self;
 }
 
-
-my $Package_Num = 0;
 sub new_from_context {
   my ($package, %args) = @_;
   
   # XXX Read the META.yml and see whether we need to run the Build.PL
   
-  # Run each Build.PL in its own package to avoid conflicts.
-  eval sprintf q{
-      package %s;
-      do './Build.PL';
-  }, "Module::Build::Build_PL::PACK".$Package_Num++;
-
+  # Run the Build.PL
+  $package->run_perl_script('Build.PL');
   my $self = $package->resume;
   $self->merge_args(undef, %args);
   return $self;
@@ -945,8 +939,8 @@ sub make_executable {
 
 sub _startperl { shift()->{config}{startperl} }
 
-# Return any directories which are not in the default @INC for this
-# Perl.  For example, stuff passed in with -I.
+# Return any directories in @INC which are not in the default @INC for
+# this perl.  For example, stuff passed in with -I or loaded with "use lib".
 sub _added_to_INC {
   my $self = shift;
 
@@ -961,9 +955,9 @@ sub _default_INC {
 
   local $ENV{PERL5LIB};  # this is not considered part of the default.
 
-  my $perl = $self->perl;
+  my $perl = ref($self) ? $self->perl : $self->find_perl_interpreter;
 
-  my @inc =`$perl -le "print join qq[\n], \@INC"`;
+  my @inc = `$perl -le "print for \@INC"`;
   chomp @inc;
 
   return @inc;
@@ -1460,7 +1454,6 @@ sub process_PL_files {
   my $files = $self->find_PL_files;
   
   while (my ($file, $to) = each %$files) {
-    local $ENV{'PERL5LIB'} = join $self->{config}{path_sep}, @INC;
     unless ($self->up_to_date( $file, $to )) {
       $self->run_perl_script($file, [], [@$to]);
       $self->add_to_cleanup(@$to);
@@ -2083,7 +2076,6 @@ sub ACTION_disttest {
   chdir $dist_dir or die "Cannot chdir to $dist_dir: $!";
   # XXX could be different names for scripts
   
-  local $ENV{'PERL5LIB'} = join $self->{config}{path_sep}, @INC;
   $self->run_perl_script('Build.PL') or die "Error executing 'Build.PL' in dist directory: $!";
   $self->run_perl_script('Build') or die "Error executing 'Build' in dist directory: $!";
   $self->run_perl_script('Build', [], ['test']) or die "Error executing 'Build test' in dist directory";
@@ -2604,7 +2596,11 @@ sub run_perl_script {
     $_ = [ $self->split_like_shell($_) ] unless ref();
   }
   my $perl = ref($self) ? $self->perl : $self->find_perl_interpreter;
-  
+
+  # Make sure our local additions to @INC are propagated to the subprocess
+  my $c = ref $self ? $self->config : \%Config::Config;
+  local $ENV{PERL5LIB} = join $c->{path_sep}, $self->_added_to_INC;
+
   return $self->do_system($perl, @$preargs, $script, @$postargs);
 }
 
